@@ -285,7 +285,8 @@ def index_embeddings(
         index_path = index_path,
         index_infos_path = str(index_folder / index_infos_file),
         max_index_memory_usage = max_index_memory_usage,
-        current_memory_available = current_memory_available
+        current_memory_available = current_memory_available,
+        should_be_memory_mappable = True
     )
 
     index = faiss.read_index(index_path, faiss.IO_FLAG_MMAP | faiss.IO_FLAG_READ_ONLY)
@@ -349,7 +350,8 @@ def chunks_to_precalculated_knn_(
     index, embeddings = chunks_to_index_and_embed(
         num_chunks = num_chunks,
         chunk_size = chunk_size,
-        chunk_memmap_path = chunk_memmap_path
+        chunk_memmap_path = chunk_memmap_path,
+        **index_kwargs
     )
 
     chunk_path = Path(chunk_memmap_path)
@@ -390,3 +392,4 @@ def chunks_to_precalculated_knn_(
             print(f'knns calculated for {dim_slice.stop} / {num_chunks}')
 
     print(f'knn saved to {knn_path}')
+    return knn_path
